==> safecheck-0.9.8.8.jar: safecheck/sqls/FetchUserFileByOrgNoRuHuSX.sql <==
select * from(select 
	ui.f_userinfo_id,
	f_userinfo_code,
	f_street,
	f_building,
	f_unit,
	f_residential_area,
	f_floor,
	f_room,
	f_address,
	{
	month != $$ :
	$
	1 code,
	$,
	$$
	}
	f_user_name,
	f_user_phone,
	ui.f_user_type,
	f_last_check_state,f_last_check_date,ui.version ,
	ui.f_filiale
 from t_userinfo ui
where {condition} and ui.f_userinfo_id is not null AND ui.f_user_state  = '正常'
{
		f_usertype != $$:
		$
		And f_user_type = '{f_usertype}' $,
		$$
}
{
	f_OrgStr != $$ :
	$
and	 ui.f_filialeids like '{f_filialeids}%'
	$,
	f_OrgStr == $$ :
	$
	and 1=1
	$,
	$$
}
{
	month != $$ :
	$
	and  datediff(month,f_last_check_date, getdate())>={month}
	$,
	month == $$ :
	$
  and	1=1
	$,
	$$
}
{
SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $$ :
  $
	and  ( isnull(f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
	$,
	 SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $是$ :
  $
  and  ( isnull(f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
  and ( DATEADD(month,{safeCycle},isnull(f_last_check_date,f_createfile_date)) <= GETDATE())
  $,
  SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $否$ :
  $
  and  ( isnull(f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
  and ( DATEADD(month,{safeCycle},isnull(f_last_check_date,f_createfile_date)) >= GETDATE())
  $,
	$$
}
{
	SafeCheckSX.f_check_start != $$  :
	$
	and  f_issued_time >= '{SafeCheckSX.f_check_start}'
	$,
	SafeCheckSX.f_check_start == $$ :
	$
	and  1 = 1
	$,
	$$
}
{
	SafeCheckSX.f_check_end != $$  :
	$
	and  f_issued_time <= '{SafeCheckSX.f_check_end}'
	$,
	SafeCheckSX.f_check_end == $$ :
	$
	and  1 = 1
	$,
	$$
}
) a
order by {orderitem}

==> safecheck-1.0.4.12.jar: safecheck/sqls/FetchUserFileByOrgNoRuHuSX.sql <==
select * from(select 
	ui.f_userinfo_id,
	f_userinfo_code,
	f_street,
	f_building,
	f_unit,
	f_residential_area,
	f_floor,
	f_room,
	f_address,
-- 	f_user_family_remarks,
	{
	month != $$ :
	$
	1 code,
	$,
	$$
	}
	f_user_name,
	f_user_phone,
	ui.f_user_type,
	f_last_check_state,f_last_check_date,ui.version ,
	ui.f_filiale
-- 		de.f_devices_type
 from t_userinfo ui
-- 		left join t_devices de on ui.f_userinfo_id =de.f_userinfo_id
where {condition} and ui.f_userinfo_id is not null AND ui.f_user_state  = '正常'
{
		f_usertype != $$:
		$
		And f_user_type = '{f_usertype}' $,
		$$
}
{
	f_OrgStr != $$ :
	$
and	 ui.f_filialeids like '{f_filialeids}%'
	$,
	f_OrgStr == $$ :
	$
	and 1=1
	$,
	$$
}
{
	month != $$ :
	$
	and  datediff(month,f_last_check_date, getdate())>={month}
	$,
	month == $$ :
	$
  and	1=1
	$,
	$$
}
{
SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $$ :
  $
	and  ( isnull(f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
	$,
	 SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $是$ :
  $
  and  ( isnull(f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
  and ( DATEADD(month,{safeCycle},isnull(f_last_check_date,f_createfile_date)) <= GETDATE())
  $,
  SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $否$ :
  $
  and  ( isnull(f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
  and ( DATEADD(month,{safeCycle},isnull(f_last_check_date,f_createfile_date)) >= GETDATE())
  $,
	$$
}
{
	SafeCheckSX.f_check_start != $$  :
	$
	and  f_issued_time >= '{SafeCheckSX.f_check_start}'
	$,
	SafeCheckSX.f_check_start == $$ :
	$
	and  1 = 1
	$,
	$$
}
{
	SafeCheckSX.f_check_end != $$  :
	$
	and  f_issued_time <= '{SafeCheckSX.f_check_end}'
	$,
	SafeCheckSX.f_check_end == $$ :
	$
	and  1 = 1
	$,
	$$
}
) a
order by {orderitem}
